@@ -6,12 +6,21 @@
 # define UNLINKED_XMOD_zshQssched 1
 #endif
 #ifdef DYNAMIC
+# define UNLINKED_XMOD_zshQshlgroup 1
+#endif
+#ifdef DYNAMIC
+# define UNLINKED_XMOD_zshQsksh93 1
+#endif
+#ifdef DYNAMIC
 # define UNLINKED_XMOD_zshQsparamQsprivate 1
 #endif
 #ifdef DYNAMIC
 # define UNLINKED_XMOD_zshQsparameter 1
 #endif
 #ifdef DYNAMIC
+# define UNLINKED_XMOD_zshQsrandom 1
+#endif
+#ifdef DYNAMIC
 # define UNLINKED_XMOD_zshQstermcap 1
 #endif
 #ifdef DYNAMIC
